@@ -19,6 +19,8 @@ Catalyst Form.
 =cut
 
 has '+item_class' => ( default => 'Book' );
+has '+widget_name_space' => ( default => sub { ['BookDB::Form::Widget'] } );
+has '+widget_wrapper' => ( default => 'Para' );
 
 has_field 'title'  => (
 				type => 'Text',
